@@ -156,6 +156,7 @@ __all__ = (
     "DescribeTransitGatewayRouteTablesPaginatorName",
     "DescribeTransitGatewayVpcAttachmentsPaginatorName",
     "DescribeTransitGatewaysPaginatorName",
+    "DescribeTrunkInterfaceAssociationsPaginatorName",
     "DescribeVolumeStatusPaginatorName",
     "DescribeVolumesModificationsPaginatorName",
     "DescribeVolumesPaginatorName",
@@ -600,6 +601,7 @@ DescribeTransitGatewayVpcAttachmentsPaginatorName = Literal[
     "describe_transit_gateway_vpc_attachments"
 ]
 DescribeTransitGatewaysPaginatorName = Literal["describe_transit_gateways"]
+DescribeTrunkInterfaceAssociationsPaginatorName = Literal["describe_trunk_interface_associations"]
 DescribeVolumeStatusPaginatorName = Literal["describe_volume_status"]
 DescribeVolumesModificationsPaginatorName = Literal["describe_volumes_modifications"]
 DescribeVolumesPaginatorName = Literal["describe_volumes"]
@@ -991,6 +993,15 @@ InstanceTypeType = Literal[
     "m6gd.medium",
     "m6gd.metal",
     "m6gd.xlarge",
+    "m6i.12xlarge",
+    "m6i.16xlarge",
+    "m6i.24xlarge",
+    "m6i.2xlarge",
+    "m6i.32xlarge",
+    "m6i.4xlarge",
+    "m6i.8xlarge",
+    "m6i.large",
+    "m6i.xlarge",
     "mac1.metal",
     "p2.16xlarge",
     "p2.8xlarge",
